@@ -1,12 +1,12 @@
 package Firefox::Application;
 use strict;
 
-use MozRepl::RemoteObject;
-use URI;
+use MozRepl::RemoteObject ();
+use URI ();
 use Carp qw(carp croak);
 
 use vars qw'$VERSION';
-$VERSION = '0.61';
+$VERSION = '0.62';
 
 =head1 NAME
 
